/*
 * SonarQube
 * Copyright (C) 2009-2016 SonarSource SA
 * mailto:contact AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.server.computation.component;

import com.google.common.base.Function;
import javax.annotation.Nonnull;

public final class ComponentFunctions {

  private ComponentFunctions() {
    // prevents instantiation
  }

  public static Function<Component, Integer> toReportRef() {
    return ToReportRef.INSTANCE;
  }

  public static Function<Component, String> toKey() {
    return ToKey.INSTANCE;
  }

  private enum ToKey implements Function<Component, String> {
    INSTANCE;

    @Override
    @Nonnull
    public String apply(@Nonnull Component input) {
      return input.getKey();
    }
  }

  private enum ToReportRef implements Function<Component, Integer> {
    INSTANCE;
    @Override
    @Nonnull
    public Integer apply(@Nonnull Component input) {
      return input.getReportAttributes().getRef();
    }

  }
}
